%% Housekeeping and working directory 
clear; clc; close all hidden;
addpath('data_quarterly')
addpath('utilities')
addpath('ADF_test_functions')


%% Converting dates from numerical values to datetime
%dates = datetime(Dates,'convertfrom', 'Excel');

%% Data loading 
load("dates.mat");
load("brentspot");
load('CPI_US')
load("rgdp_industry.mat");
load("GECON.mat"); 
load("oilprod.mat");
load("empl_industry_sector.mat");
load("wage_industry_sector.mat");
load('KPI_Norway');


%% Plots of data 
% Do subplot when all data is collected
figure(1)
subplot(3, 3, 1); plot(dates(1:111), oilprod); title('Global Crude Oil Production');
subplot(3, 3, 2); plot(dates, GECON); title('Global Economic Conditions Indicator');
subplot(3, 3, 3); plot(dates,  brentspot); title('Euorope Brent Spot Prices of Crude Oil');
subplot(3, 3, 4); plot(dates, rgdp_industry); title('Industry RGDP Norway');
subplot(3, 3, 5); plot(dates, empl_industry_sector); title('Employment in Industry Sector');
subplot(3, 3, 6); plot(dates, wage_industry_sector); title('Wage in Industry Sector');
set(findobj(gcf,'type','Line'),'LineWidth', 1.5);

%% Converting nominal values to real value 

rop = (brentspot./CPI_US)*100; %Real oil price 
real_wage_industry_sector = (wage_industry_sector./KPI_Norway)*100; %Real wage 

%% First difference of Natural log 

oilprod_detrended = detrend(log(oilprod),1);
rgdp_detrended = detrend(log(rgdp_industry),1);
rop_log=(log(rop));
real_wage_industry_sector_detrended = detrend(log(real_wage_industry_sector),1);
empl_industry_sector_detrended = detrend(log(empl_industry_sector),1);



%% Plot estimated data

figure(3)
subplot(3, 3, 1); plot(dates(1:111), oilprod_detrended); title('Global Crude Oil Production');
subplot(3, 3, 2); plot(dates, GECON); title('Global Economic Conditions Indicator');
subplot(3, 3, 3); plot(dates, rop_log); title('Real Oil Prices');
subplot(3, 3, 4); plot(dates, rgdp_detrended); title('Industry RGDP Norway');
subplot(3, 3, 5); plot(dates,empl_industry_sector_detrended); title('Employment in Industry Sector');
subplot(3, 3, 6); plot(dates,real_wage_industry_sector_detrended); title('Real Wage in Industry Sector');
set(findobj(gcf,'type','Line'),'LineWidth', 1.5);


%% Creating a Vector of our variables 

Y = [oilprod_detrended,GECON(1:111),rop_log(1:111),rgdp_detrended(1:111),empl_industry_sector_detrended(1:111), real_wage_industry_sector_detrended(1:111)]
y_Names = {'Global Crude Oil Production',...
          'GECON indicator',...
          'Real Oil Prices',...
          'Industry Real GDP Norway',...
          'Employment in Industry Sector',...
          'Real Wage in Industry Sector'};

%% Check for Stability
% Specify number of lags (result from the section above)
nlag_max = 1; 

% Specify deterministic variables
% deterministic = 0: do not include constant or trend
% deterministic = 1: include constant
% deterministic = 2: include constant and linear trend
deterministic = 2;

% Estimate the VAR
varModel = estimateVAR(Y, nlag_max, deterministic);


% Check for stability using eigenvalues
max_eigvals = max(abs(eig(varModel.betac)));
fprintf('Maximum eigenvalue of the companion form matrix is %g\n',max_eigvals)

% Conclusion: 
% The VAR is stable because all eigenvalues are less than one in absolute value.

%% Computing IRFs 
% Number of bootstraps (to simulate confidence bands)
draws = 1000;

% Impulse-response horizon
nirf = 60; % 10 years = 40 quarters

% Specify confidence bands
percentiles = [0.05, 0.95]; % 90% confidence bands  

% Normalise the shock size to 1% 
normalizeShocks = 1;

% Compute the SVAR model using Cholesky decomposition 
svarModel = cholIdentification(varModel, draws, nirf, percentiles, normalizeShocks);

% Plot impulse response functions
plotIRF(svarModel, y_Names)

% Interpret 
